@@ -19,6 +19,11 @@ if sys.version_info[0] < 3:  # no cov
             # this is to support any `isinstance(metadata_entry, str)`
             return byteify_object(toml.loads(f.read()))
 
+    def ensure_string(obj):
+        if not isinstance(obj, bytes):
+            return obj.encode('utf-8')
+        return obj
+
 else:
     import tomli
 
@@ -26,6 +31,9 @@ else:
         with open(path, 'r', encoding='utf-8') as f:
             return tomli.loads(f.read())
 
+    def ensure_string(obj):
+        return obj
+
 
 class ProjectMetadata(object):
     def __init__(self, root, plugin_manager, config=None):
@@ -380,6 +388,8 @@ class CoreMetadata(object):
             else:
                 raise TypeError('Field `project.readme` must be a string or a table')
 
+            self._readme = ensure_string(self._readme)
+
         return self._readme
 
     @property
